==> nextcloud-app-richdocuments-1.1.25-3-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/ru.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Сохранение...",
    "Download this revision" : "Скачать эту ревизию",
    "Restore this revision" : "Восстановить эту ревизию",
    "Latest revision" : "Крайняя ревизия",
    "More versions..." : "Ещё версии...",
    "Just now" : "Прямо сейчас",
    "Failed to revert the document to older version" : "Не удалось вернуть документ к старой версии",
    "Save" : "Сохранить",
    "Loading documents..." : "Загрузка документов...",
    "Edit" : "Редактировать",
    "View" : "Просмотр",
    "Document" : "Документ",
    "Spreadsheet" : "Таблица",
    "Presentation" : "Презентация",
    "Could not create file" : "Не удалось создать файл",
    "New Document.odt" : "Новый Документ.odt",
    "New Spreadsheet.ods" : "Новая Таблица.ods",
    "New Presentation.odp" : "Новая Презентация.odp",
    "New Document.docx" : "Новый Документ.docx",
    "New Spreadsheet.xlsx" : "Новая Таблица.xlsx",
    "New Presentation.pptx" : "Новая Презентация.pptx",
    "Can't create document" : "Невозможно создать документ",
    "Saved" : "Сохранено",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Сохранено с ошибкой: В Collabra Online должен использоваться тот же протокол, что в установке сервера.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Сервер Collabora Online",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (и порт) сервера Collabora Online, который предоставляет возможность редактирования, как клиент WOPI.",
    "Apply" : "Применить",
    "Use OOXML by default for new files" : "Для новых файлов по умолчанию использовать OOXML",
    "Wrong password. Please retry." : "Неправильный пароль. Повторите попытку.",
    "Password" : "Пароль",
    "OK" : "ОК",
    "Guest %s" : "Гость %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Срок действия ссылки истек, либо ссылка никогда не существовала. Пожалуйста, обратитесь к человеку, который поделился ею, за подробностями."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-richdocuments-1.12.31-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/richdocuments/l10n/ru.js <==
OC.L10N.register(
    "richdocuments",
    {
    "Saving..." : "Сохранение...",
    "Download this revision" : "Скачать эту ревизию",
    "Restore this revision" : "Восстановить эту ревизию",
    "Latest revision" : "Крайняя ревизия",
    "More versions..." : "Ещё версии...",
    "Just now" : "Прямо сейчас",
    "Failed to revert the document to older version" : "Не удалось вернуть документ к старой версии",
    "Save" : "Сохранить",
    "Loading documents..." : "Загрузка документов...",
    "Edit" : "Редактировать",
    "New Document" : "Новый документ",
    "New Spreadsheet" : "Новая таблица",
    "New Presentation" : "Новая презентация",
    "Could not create file" : "Не удалось создать файл",
    "New Document.odt" : "Новый Документ.odt",
    "New Spreadsheet.ods" : "Новая Таблица.ods",
    "New Presentation.odp" : "Новая Презентация.odp",
    "New Document.docx" : "Новый Документ.docx",
    "New Spreadsheet.xlsx" : "Новая Таблица.xlsx",
    "New Presentation.pptx" : "Новая Презентация.pptx",
    "Can't create document" : "Невозможно создать документ",
    "Saved" : "Сохранено",
    "Saved with error: Collabora Online should use the same protocol as the server installation." : "Сохранено с ошибкой: В Collabra Online должен использоваться тот же протокол, что в установке сервера.",
    "Collabora Online" : "Collabora Online",
    "Collabora Online server" : "Сервер Collabora Online",
    "URL (and port) of the Collabora Online server that provides the editing functionality as a WOPI client." : "URL (и порт) сервера Collabora Online, который предоставляет возможность редактирования, как клиент WOPI.",
    "Apply" : "Применить",
    "Use OOXML by default for new files" : "Для новых файлов по умолчанию использовать OOXML",
    "Wrong password. Please retry." : "Неправильный пароль. Повторите попытку.",
    "Password" : "Пароль",
    "OK" : "ОК",
    "Guest %s" : "Гость %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Срок действия ссылки истек, либо ссылка никогда не существовала. Пожалуйста, обратитесь к человеку, который поделился ею, за подробностями."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
